API Documentation
=================

Bitwuzla provides APIs for several programming languages.
The :doc:`C++ interface <cpp/api>` is Bitwuzla's primary interface,
the :doc:`C <c/api>` and :doc:`Python <python/api>` APIs are
built as thin wrappers on top of the C++ API.

.. toctree::
  :maxdepth: 2

  cpp/api
  c/api
  python/api
  ocaml/api
